@@ -1906,7 +1906,8 @@ gnome_rr_output_is_laptop (GnomeRROutput *output)
 	    strstr (output->name, "LVDS") ||
 	    strstr (output->name, "Lvds") ||
 	    strstr (output->name, "LCD")  ||  /* ... but fglrx uses "LCD" in some versions.  Shoot me now, kthxbye. */
-	    strstr (output->name, "eDP")))    /* eDP is for internal laptop panel connections */
+	    strstr (output->name, "eDP")  ||  /* eDP is for internal laptop panel connections */
+	    strstr (output->name, "DFP")))    /* DFP is also an internal laptop display */
 	return TRUE;
 
     return FALSE;
